""" Logging module constants """
REQUEST_KEY = 'request'
RESPONSE_KEY = 'response'

LOG_SENSITIVE_CONNECTION_DATA = 'LOG_SENSITIVE_CONNECTION_DATA'
LOG_REMOTE_USER = 'LOG_REMOTE_USER'
LOG_REFERER = 'LOG_REFERER'

STACKTRACE_MAX_SIZE = 55 * 1024
