""" Default values used inside the framework """
import logging

from datetime import datetime


UNKNOWN = '-'
REDACTED = 'redacted'
RESPONSE_SIZE_B = -1
RESPONSE_TIME_MS = 0
REQUEST_SIZE_B = -1
STATUS = -1

DEFAULT_LOGGING_LEVEL = logging.INFO

UNIX_EPOCH = datetime(1970, 1, 1)
